<template>
    <div class="row">
        <div class="col-md-6 col-xs-12">
            <div class="form-group">
                <label for="billingName">Nombre</label>
                <input
                    id="billingName"
                    v-model="billingName"
                    :class="{ 'input-error': !billingName?.trim() && isFormBillingSubmitted }"
                    class="form-control"
                    placeholder="Nombre"
                    autocomplete="off"
                />
            </div>
        </div>
        <div class="col-md-6 col-xs-12">
            <div class="form-group">
                <label for="billingSurname">Apellido</label>
                <input
                    id="billingSurname"
                    v-model="billingSurname"
                    :class="{ 'input-error': !billingSurname?.trim() && isFormBillingSubmitted }"
                    class="form-control"
                    placeholder="Apellido"
                    autocomplete="off"
                />
            </div>
        </div>
        <div class="col-md-6 col-xs-12">
            <div class="form-group">
                <label for="billingDni">DNI</label>
                <input
                    id="billingDni"
                    v-model="billingDni"
                    :class="{ 'input-error': (!isDniValid() || !billingDni?.trim()) && isFormBillingSubmitted }"
                    class="form-control"
                    placeholder="DNI"
                    autocomplete="off"
                />
            </div>
        </div>
        <div class="col-md-6 col-xs-12">
            <div class="form-group billingPhone-class">
                <label for="billingPhone">Teléfono</label>
                <input
                    id="billingPhone"
                    ref="billingPhoneInput"
                    v-model="billingPhone"
                    :class="{
                        'input-error': (!isPhoneNumberValid() || !billingPhone?.trim()) && isFormBillingSubmitted,
                    }"
                    class="form-control"
                    placeholder="Teléfono"
                    autocomplete="off"
                />
            </div>
        </div>
        <div class="col-md-12 col-xs-12">
            <div class="form-group">
                <label for="billingEmail">E-mail</label>
                <input
                    id="billingEmail"
                    v-model="billingEmail"
                    :class="{ 'input-error': (!isEmailValid() || !billingEmail?.trim()) && isFormBillingSubmitted }"
                    class="form-control"
                    placeholder="Email"
                    autocomplete="off"
                />
            </div>
        </div>
    </div>

    <div class="row">
        <div class="col-md-12">
            <label>
                <input v-model="wantInvoice" type="checkbox" />
                Quiero Factura A
            </label>
        </div>

        <template v-if="wantInvoice">
            <!-- CUIT -->
            <div class="col-md-6">
                <div class="form-group">
                    <label for="invoicingCuit">CUIT</label>
                    <input
                        id="invoicingCuit"
                        v-model="invoicingCuit"
                        class="form-control"
                        :class="{ 'input-error': (!isCuitValid() || !invoicingCuit?.trim()) && isFormBillingSubmitted }"
                        placeholder="CUIT"
                        autocomplete="off"
                    />
                </div>
            </div>

            <!-- Razón Social -->
            <div class="col-md-6">
                <div class="form-group">
                    <label for="invoicingCompanyName">Razón Social</label>
                    <input
                        id="invoicingCompanyName"
                        v-model="invoicingCompanyName"
                        class="form-control"
                        :class="{ 'input-error': !invoicingCompanyName?.trim() && isFormBillingSubmitted }"
                        placeholder="Razón Social"
                        autocomplete="off"
                    />
                </div>
            </div>

            <!-- Domicilio -->
            <div class="col-md-6">
                <div class="form-group">
                    <label for="invoicingAddress">Domicilio</label>
                    <input
                        id="invoicingAddress"
                        v-model="invoicingAddress"
                        class="form-control"
                        :class="{ 'input-error': !invoicingAddress?.trim() && isFormBillingSubmitted }"
                        placeholder="Domicilio"
                        autocomplete="off"
                    />
                </div>
            </div>

            <!-- Localidad (con Vue Select y búsqueda dinámica) -->
            <div class="col-md-6">
                <div class="form-group">
                    <label for="invoicingCity">Localidad</label>
                    <div :class="{ 'input-error': !invoicingCity && isFormBillingSubmitted }">
                        <v-select
                            v-model="invoicingCity"
                            :options="cities"
                            :filterable="false"
                            label="name"
                            placeholder="Buscar localidad..."
                            @search="fetchCities"
                        >
                            <template #option="{ name }">
                                <span>{{ name }}</span>
                            </template>
                            <template #no-options>Sin resultados.</template>
                        </v-select>
                    </div>
                </div>
            </div>
        </template>
    </div>
</template>

<script setup>
import { ref, defineExpose, watch, onMounted, onBeforeUnmount, nextTick } from "vue";
import { cartStore } from "../../../js/stores/cart.js";
import intlTelInput from "intl-tel-input";
import "intl-tel-input/build/css/intlTelInput.css";
import vSelect from "vue-select";
import "vue-select/dist/vue-select.css";

const store = cartStore();
const isFormBillingSubmitted = ref(false);

const billingName = ref(store.billingName || "");
const billingSurname = ref(store.billingSurname || "");
const billingDni = ref(store.billingDni || "");
const billingEmail = ref(store.billingEmail || "");
const billingPhone = ref(store.billingPhone || "");

const wantInvoice = ref(store.wantInvoice || false);
const invoicingCuit = ref(store.invoicingCuit || "");
const invoicingAddress = ref(store.invoicingAddress || "");
const invoicingCompanyName = ref(store.invoicingCompanyName || "");
const invoicingCity = ref(store.invoicingCity);

const billingPhoneInput = ref(null);
let intlTelInstance = null;

const initializeIntlTelInput = () => {
    if (!billingPhoneInput.value) return;

    intlTelInstance = intlTelInput(billingPhoneInput.value, {
        initialCountry: "ar",
        utilsScript: "https://cdnjs.cloudflare.com/ajax/libs/intl-tel-input/17.0.8/js/utils.js",
    });

    billingPhoneInput.value.addEventListener("countrychange", onCountryChange);
};

const onCountryChange = () => {
    const selectedCountry = intlTelInstance.getSelectedCountryData();
    console.log("País seleccionado:", selectedCountry);
};

const isEmailValid = () => {
    const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
    return emailRegex.test(billingEmail.value.trim());
};

const isDniValid = () => {
    const dniString = String(billingDni.value).trim();
    const dniRegex = /^[0-9]{1,8}$/;

    return dniString && dniRegex.test(dniString);
};

const isCuitValid = () => {
    const cuitString = String(invoicingCuit.value).trim();
    const cuitRegex = /^[0-9]{2}[0-9]{8}[0-9]{1}$/;

    return cuitString && cuitRegex.test(cuitString);
};

const isPhoneNumberValid = () => {
    const phoneRegex = /^[0-9]{10,15}$/;
    return phoneRegex.test(billingPhone.value.trim());
};

const validateBillingForm = () => {
    isFormBillingSubmitted.value = true;

    const fields = {
        billingName,
        billingSurname,
        billingDni,
        billingEmail,
        billingPhone,
    };

    if (wantInvoice.value) {
        Object.assign(fields, {
            invoicingCuit,
            invoicingCompanyName,
            invoicingAddress,
            invoicingCity,
        });
    }

    // Validamos cada campo
    for (const [key, field] of Object.entries(fields)) {
        const fieldValue = field.value;

        if (typeof fieldValue === "string" && !fieldValue.trim()) {
            scrollToField(key);
            return false;
        }

        if (fieldValue == null || (Array.isArray(fieldValue) && fieldValue.length === 0)) {
            scrollToField(key);
            return false;
        }
    }

    if (!isDniValid()) {
        scrollToField("billingDni");
        return false;
    }

    if (!isPhoneNumberValid()) {
        scrollToField("billingPhone");
        return false;
    }

    if (!isEmailValid()) {
        scrollToField("billingEmail");
        return false;
    }

    if (wantInvoice.value && !isCuitValid()) {
        scrollToField("invoicingCuit");
        return false;
    }

    return true;
};

const scrollToField = (fieldId) => {
    nextTick(() => {
        const input = document.querySelector(`label[for=${fieldId}]`);
        if (input) {
            const rect = input.getBoundingClientRect();
            const scrollTop = window.pageYOffset || document.documentElement.scrollTop;

            const targetPosition = rect.top + scrollTop - 150;

            smoothScrollTo(targetPosition);
        }
    });
};

const smoothScrollTo = (targetPosition) => {
    const currentPosition = window.pageYOffset || document.documentElement.scrollTop;
    const distance = targetPosition - currentPosition;
    const duration = 700;
    let startTime;

    const animateScroll = (timestamp) => {
        if (!startTime) startTime = timestamp;
        const progress = timestamp - startTime;
        const scrollStep = Math.min(progress / duration, 1);

        window.scrollTo(0, currentPosition + distance * scrollStep);

        if (progress < duration) {
            requestAnimationFrame(animateScroll);
        }
    };

    requestAnimationFrame(animateScroll);
};

onBeforeUnmount(() => {
    if (intlTelInstance) {
        intlTelInstance.destroy();
    }
});

onMounted(() => {
    initializeIntlTelInput();
});

// const selectedCity = ref(null);
const cities = ref([]); // <- Asegúrate de que es un array vacío al inicio

const fetchCities = async (search) => {
    if (!search) return;

    try {
        const response = await fetch(`/api/cities/${encodeURIComponent(search)}/search`);
        const data = await response.json();
        cities.value = data["hydra:member"] || [];
    } catch (error) {
        console.error("Error al buscar localidades", error);
        cities.value = [];
    }
};

watch(billingName, (value) => store.updateBillingName(value));
watch(billingSurname, (value) => store.updateBillingSurname(value));
watch(billingDni, (value) => store.updateBillingDni(value));
watch(billingEmail, (value) => store.updateBillingEmail(value));
watch(billingPhone, (value) => store.updateBillingPhone(value));
watch(wantInvoice, (value) => store.updateWantInvoice(value));
watch(invoicingCuit, (value) => store.updateInvoicingCuit(value));
watch(invoicingAddress, (value) => store.updateInvoicingAddress(value));
watch(invoicingCompanyName, (value) => store.updateInvoicingCompanyName(value));
watch(invoicingCity, (value) => store.updateInvoicingCity(value));

defineExpose({ validateBillingForm });
</script>

<style scoped>
.input-error {
    border: 1px solid #ff00007a;
    border-radius: 5px;
}
</style>
